#!/bin/sh
###############################################################################
#
#   Vrand/SMS CDROM Installation Script
#
#   Modified on: 2008-12-12 By Brian C. Watson for VRAND/SMS 10.1
#
###############################################################################
SMSVER=10.1
#
#  remember location of installation files
#
FROMDIR=`dirname $0`
if [ "$FROMDIR" = "." ]; then
   FROMDIR=`pwd`
elif [ `expr $FROMDIR : '\(.\).*'` != '/' ]; then
   FROMDIR=`pwd`/$FROMDIR
fi
PATH=/usr/bin:/bin:/usr/sbin:/sbin:/usr/bsd
export PATH
#
for file in $FROMDIR/* $FROMDIR/unix/* $FROMDIR/UNIX/*
do
   if [ -f "$file" ]; then
      case "$file" in
         */license.txt*|*/LICENSE.TXT*) LICFILE="$file"
            ;;
         */smssun.tz*|*/SMSSUN.TZ*) SMSSUN="$file"
            ;;
         */smsatx.tz*|*/SMSATX.TZ*) SMSATX="$file"
            ;;
         */smslnx.tz*|*/SMSLNX.TZ*) SMSLNX="$file"
            ;;
         */smslnx32.tz*|*/SMSLNX32.TZ*) SMSLNX32="$file"
            ;;
         */smshp.tz*|*/SMSHP.TZ*) SMSHP="$file"
            ;;
         */smshpi.tz*|*/SMSHPI.TZ*) SMSHPI="$file"
            ;;
         */smsibm.tz*|*/SMSIBM.TZ*) SMSIBM="$file"
            ;;
         */smsmi.tz*|*/SMSMI.TZ*) SMSMI="$file"
            ;;
         */vrandsms.tpl*|*/VRANDSMS.TPL*) VRANDSMS="$file"
            ;;
         */nassms.tpl*|*/NASSMS.TPL*) NASSMS="$file"
            ;;
         */lmu.tpl*|*/LMU.TPL*) LMU="$file"
            ;;
         */lmg.tpl*|*/LMG.TPL*) LMG="$file"
            ;;
         */flexlm.tz*|*/FLEXLM.TZ*) FLEXLM="$file"
            ;;
      esac
   elif [ -d "$file" ]; then
      case "$file" in
         */manuals|*/MANUALS) MANDIR="$file"
            ;;
      esac
   fi
done
#
INSSCRIPT=`basename $0`
Usage() {
   printf "Usage: $FROMDIR/$INSSCRIPT
        Install Vrand/SMS.\n" >&2
}
#
###############################################################################
#
# Function: Banner
#
# Purpose: print a banner message
#
# Notes:  
#
###############################################################################
Banner() {
clear
printf "\n
                VRAND/SMS ${SMSVER} Workstation/Server Installation
\n\n"
}
###############################################################################
#
# Function: GetYesNo
#
# Purpose: prompt the user to enter yes or no
#
# Notes:   Sets ANS to "YES" or "NO"
#
###############################################################################
GetYesNo() {
   ANS=""
   while [ "x$ANS" = "x" ]; do
      printf "
   (y) Yes 
   (n) No
?"
      read ans
      case "$ans" in
         y|yes|Y|YES) return 0
            ;;
         n|no|N|NO) return 1
            ;;
         *) printf ""
            ;;
      esac
   done
}
###############################################################################
#
# Function: PressReturn
#
# Purpose: prompt the user to press return to continue
#
# Notes:   
#
###############################################################################
PressReturn() {
   printf "\nPress RETURN to continue"
   read ans
}
###############################################################################
#
# Function: DeTar
#
# Purpose: Untar a package
#
# Notes:   
#
###############################################################################
DeTar() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $2 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      tar xf "$1" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarOnly
#
# Purpose: Untar a package
#
# Notes:   
#
###############################################################################
DeTarOnly() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $3 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      tar xf "$1" "$2" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarZ
#
# Purpose: Untar a compressed package
#
# Notes:   
#
###############################################################################
DeTarZ() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $2 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      zcat < "$1" | tar xf - 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarZOnly
#
# Purpose: Untar a compressed package
#
# Notes:   
#
###############################################################################
DeTarZOnly() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $3 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      zcat < "$1" | tar xf - "$2" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: Progress
#
# Purpose: Print progress indicator
#
# Notes:   
#
###############################################################################
Progress() {
   case "$1" in
      begin)
         printf "\nInstalling $2 ."
      ;;
      dot)
         printf "."
      ;;
      end)
         printf ".\n"
      ;;
   esac
}
###############################################################################
#
# Function: TestWritable
#
# Purpose: Test if a directory is writable
#
# Notes:   
#
###############################################################################
TestWritable() {
   OLDDIR=`pwd`
   cd "$1"
   if [ ! -w junk.$$ ]; then
      touch junk.$$ > /dev/null 2>&1
      if [ $? != 0 ]; then
         cd $OLDDIR
         return 1
      else
         /bin/rm -f junk.$$
         cd $OLDDIR
         return 0
      fi
   fi
   cd $OLDDIR
   return 0
}
###############################################################################
#
# Function: GetProduct
#
# Purpose: Get which product(s) the user wants to install
#
# Notes:   Sets PROD
#
###############################################################################
GetProduct() {
   finished=""
   VAL1="No"
   VAL3="No"
   test $ISSET1 = true && VAL1="Yes"
   test $ISSET3 = true && VAL3="Yes"
   while [ "x$finished" = "x" ]; do
      Banner
      printf "
Select the product(s) you wish to install:

       Product                                              Selected

   (1) VRAND/SMS External Eigenvalue Solver Software           %3s
   (2) FLEXlm server                                           %3s
" $VAL1 $VAL3
      printf "
   (c) Continue
   (q) Quit the installation

   Enter a number to toggle that selection, c to continue, or q to quit
>"
      read targ
      case "$targ" in
         1) if [ x"$VAL1" = xNo ]; then
               VAL1="Yes"
            else
               VAL1="No"
            fi
            ;;
         2) if [ x"$VAL3" = xNo ]; then
               VAL3="Yes"
            else
               VAL3="No"
            fi
            ;;
         c|C) if [ x"$VAL1" = xNo -a x"$VAL3" = xNo ]; then
                 printf "\nNothing is selected for installation!
Continuing will quit the installation.  Do you want to continue"
                 if GetYesNo; then
                    PROD="QUIT"
                    finished=true
                 fi
              else
                 finished=true
              fi
            ;;
         q|Q) PROD="QUIT"
              finished=true
            ;;
         *) printf ""
            ;;
      esac
   done

   if [ x"$PROD" = "xQUIT" ]; then
      printf "\nVRAND/SMS installation aborted.\n"
      exit 0;
   fi
   ISSET1=false
   ISSET3=false
   test $VAL1 = Yes && ISSET1=true
   test $VAL3 = Yes && ISSET3=true
}
###############################################################################
#
# Function: SetTarget
#
# Purpose: Target Combobox Callback
#
# Notes:   
#
###############################################################################
SetTarget() {
   TARGET="$1"
   case "$TARGET" in
      SunOS) TargetName="Sun Sparc (Solaris 10 or higher)"
         ;;
      Linux_ia64) TargetName="Generic ia64 (Linux 2.6 or higher)"
         ;;
      HP-UX) TargetName="HP PA-RISC (HP-UX 11i v1 or higher)"
         ;;
      HP-UX_ia64) TargetName="HP ia64 (HP-UX 11i v2 or higher)"
         ;;
      AIX) TargetName="IBM POWER 3+ (AIX 5.3 or higher)"
         ;;
      Linux_ix86) TargetName="Generic ix86/x86_64 (Linux 2.6 or higher)"
         ;;
      *) TargetName="Unknown"
         ;;
   esac
}
###############################################################################
#
# Function: SelectPlatform
#
# Purpose: prompt the user to select a computer platform
#
# Notes:   Sets TARGET to the plaform name
#          Can exit
#
###############################################################################
SelectPlatform() {
   TARGET=`uname`
   case $TARGET in
      AIX*)  TARGET="AIX" ;;
      Linux) TARGET="Linux_ix86"
         case `uname -m` in
            ia64*) TARGET="Linux_ia64" ;;
         esac
      ;;
      HP-UX)
         case `model` in
            ia64*) TARGET="HP-UX_ia64" ;;
         esac
      ;;
      SunOS) TARGET="SunOS_ix86"
         case `uname -p` in
            sparc*) TARGET="SunOS" ;;
         esac
      ;;
   esac
   SetTarget $TARGET
   Banner
   if [ x"$TargetName" != xUnknown ]; then
      printf "
The local system appears to be $TargetName.
Is this the correct target platform type"
      if GetYesNo; then
         return
      fi
   fi
   TARGET=
   while [ "x$TARGET" = "x" ]; do
      Banner
      printf "%s" '
Select the target platform type:

   (1) Generic ix86/x86_64  (Linux 2.6 or higher)
   (2) Generic ia64         (Linux 2.6 or higher)
   (3) IBM POWER 3+         (AIX 5.3 or higher)
   (4) Sun Sparc            (Solaris 10 or higher)
   (5) HP ia64              (HP-UX 11i v2 or higher)
   (6) HP PA-RISC           (HP-UX 11i v1 or higher)

   (q) Quit the installation
>'
      read targ
      case "$targ" in
         1) SetTarget Linux_ix86
            ;;
         2) SetTarget Linux_ia64
            ;;
         3) SetTarget AIX
            ;;
         4) SetTarget SunOS
            ;;
         5) SetTarget HP-UX_ia64
            ;;
         6) SetTarget HP-UX
            ;;
         q|Q) TARGET="QUIT"
            ;;
         *) printf ""
            ;;
      esac
   done

   if [ $TARGET = "QUIT" ]; then
      printf "\nVRAND/SMS installation aborted.\n"
      exit 0;
   fi
}
###############################################################################
#
# Function: VerifyDir
#
# Purpose: check that the users selected directory is OK
#
# Notes:   Sets TODIR to the directory
#          Can exit on errors
#
###############################################################################
VerifyDir() {
   if [ $ISSET1 = true ]; then
      if [ -d "$targ/vrand/sms/$TARGET" ]; then
         printf ""
         printf "
VRAND/SMS is already installed in this directory.
Do you want to continue (and overwrite the existing installation!)\n"
         if GetYesNo; then
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         else
            TODIR=
            return
         fi
      elif [ -f "$targ/vrand/sms" ]; then
         /bin/mv -f "$targ/vrand/sms" "$targ/vrand/sms_saved_file"
         if [ $? != 0 ]; then
            printf ""
            printf "\nThis directory contains a file named vrand/sms that could not be renamed!
Select a different directory.\n"
            PressReturn
            TODIR=
            return
         else
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         fi
      else
         OLDDIR=`pwd`
         cd $targ
         TODIR=`pwd`
         cd $OLDDIR
      fi
   fi
   if [ $ISSET3 = true ]; then
      OLDDIR=`pwd`
      cd $targ
      TODIR=`pwd`
      cd $OLDDIR
   fi
}
###############################################################################
#
# Function: SelectDir
#
# Purpose: prompt the user to select a directory
#
# Notes:   Sets TODIR to the directory
#          Can exit on errors
#
###############################################################################
SelectDir() {
   TODIR=""
   while [ "x$TODIR" = "x" ]; do
      Banner
      printf "
Enter the full path of the directory in which to install
(e.g., /opt or /usr/local)
or 'quit' to quit the installation
>"
      read targ
      case "$targ" in
         */vrand|*/vrand/) targ=`dirname $targ`
         ;;
      esac
      if [ -z "$targ" ]; then
         printf "\n"
      elif [ "$targ" = "quit" -o "$targ" = 'q' ]; then
         printf "\n%s\n" 'VRAND/SMS installation aborted.'
         exit 0
      elif [ -d "$targ/vrand" ]; then
         if TestWritable "$targ/vrand"; then
            VerifyDir
         else
            printf ""
            printf "\nYou do not have write-permission for $targ/vrand \n"
            PressReturn
         fi
      elif [ -d "$targ" ]; then
         if TestWritable "$targ"; then
            VerifyDir
         else
            printf ""
            printf "\nYou do not have write-permission for $targ \n"
            PressReturn
         fi
      else
         printf "
Installation directory $targ does not exist.
Do you want to create it

*** NOTE ***
All files will be installed in a directory named vrand
(created automatically) in the installation directory.
You probably want to answer 'No' and enter an existing directory
as the installation directory.
"
         if GetYesNo; then
            printf "\nCreating directory: $targ\n"
            mkdir -p "$targ"
            if [ $? != 0 ]; then
               printf ""
               printf "\nError: could not create directory\n"
               PressReturn
            else
               OLDDIR=`pwd`
               cd "$targ"
               TODIR=`pwd`
               cd "$OLDDIR"
            fi
         fi
      fi
   done
}
###############################################################################
#
# Function: GetLenvec
#
# Purpose: Get the value for the default Lenvec
#
# Notes:  
#
###############################################################################
GetLenvec() {
   if [ $ISSET1 = true ]; then
      PROMPT="Enter the default amount of memory VRAND/SMS should use (in Mb)" 
      SCRIPT="VRANDSMS"
   else
      return
   fi
   LENVEC=""
   while [ "x$LENVEC" = "x" ]; do
      Banner
      printf "
$PROMPT
(E.g., 400 or 400Mb) or 'quit' to abort
>"
      read lenv
      if [ -z "$lenv" ]; then
         printf "\n"
      elif [ "$lenv" = "quit" -o "$lenv" = 'q' ]; then
         printf "\n%s\n" 'VRAND/SMS installation aborted.'
         exit 0
      else
         units=`expr $lenv : '[0-9]*\([a-zA-Z]*\)'`
         mem=`expr $lenv : '\([0-9]*\)'`
         if [ -z "$mem" ];then
            printf "\n"
         else
            case "$units" in
               GB|gb|Gb) bytes=`expr $mem \* 1000000000`
                  ;;
               MB|mb|Mb) bytes=`expr $mem \* 1000000`
                  ;;
               KB|kb|Kb) bytes=`expr $mem \* 1000`
                  ;;
               *) bytes=`expr $mem \* 1000000`
                  ;;
            esac
            if [ $bytes -lt 16000000 ]; then
               printf ""
               printf "\n%s\n" 'VRAND/SMS requires at least 16MB to run!'
               PressReturn
            else
               LENVEC=`expr $bytes / 4`
            fi
         fi
      fi
   done
   memused=`expr $LENVEC \* 4`
   printf ""
   printf "\nConfiguring the default LENVEC to $LENVEC \n"
   printf "\nNOTE: With this configuration, VRAND/SMS will use
approximately $memused bytes of memory.\n"
   printf "\nThis can be changed by setting the environment variable
\"SMS_MEM\" before a run.\n"
   PressReturn
}
###############################################################################
#
# Function: Confirm
#
# Purpose: Confirm the user selections for platform and install dir
#
# Notes:  
#
###############################################################################
Confirm() {
   OK=""
   while [ "x$OK" = "x" ]; do
      ProdName=
      if [ $ISSET1 = true ]; then
         ProdName="$ProdName
          VRAND/SMS External Eigenvalue Solver Software"
      fi
      if [ $ISSET3 = true ]; then
         ProdName="$ProdName
          FLEXlm license server"
      fi
      Banner
      printf "\n
   (1) Product(s) $ProdName
   (2) Target Platform          = $TargetName
   (3) Install into             = $TODIR"
      if [ $ISSET1 = true ]; then
         printf "
   (4) LENVEC                   = $LENVEC"
      fi
      printf "

   (c) Continue
   (q) Quit

   Enter a number to make a change, c to continue, or q to quit:
>"
      read okans
      case "$okans" in
         1) GetProduct
            ;;
         2) SelectPlatform
            ;;
         3) SelectDir
            ;;
         4) if [ $ISSET1 = true ]; then
               GetLenvec
            else
               printf ""
            fi
            ;;
         c|C) OK="OK"
            ;;
         q|Q) OK="QUIT"
            ;;
         *) printf ""
            ;;
      esac
   done
   if [ $OK = "QUIT" ]; then
      printf "\n%s\n" 'VRAND/SMS installation aborted.'
      exit 0;
   fi
}
###############################################################################
#
# Function: AgreeYesNo
#
# Purpose: prompt the user to enter yes or no
#
# Notes:   Sets ANS to "YES" or "NO"
#
###############################################################################
AgreeYesNo() {
   ANS=""
   while [ "x$ANS" = "x" ]; do
      printf "
   (y) Yes, I agree
   (n) No, quit the installation
?"
      read ans
      case "$ans" in
         y|yes|Y|YES) return 0
            ;;
         n|no|N|NO) return 1
            ;;
         *) printf ""
            ;;
      esac
   done
}
###############################################################################
#
#  Begin main script code
#
###############################################################################
if [ ! -f "$LICFILE" ]; then
   printf ""
   printf "\nError: Cannot locate the installation files.
       Installation aborted.\n"
   exit 1
fi
more "$LICFILE"
printf "\nDo you agree to the license terms"
AgreeYesNo || exit 0
ISSET1=true
ISSET3=true
GetProduct
SelectPlatform
SelectDir
GetLenvec
Confirm
   INSTALLLOG="$TODIR/vrand/sms_install.log"
   test -f "$INSTALLLOG" && mv "$INSTALLLOG" "${INSTALLLOG}.old"
   if [ $ISSET1 = true ]; then
      SOURCE32=""
      case "$TARGET" in
         SunOS)     SOURCE="$SMSSUN" ;;
         Linux_ia64) SOURCE="$SMSATX" ;;
         Linux_ix86)SOURCE="$SMSLNX"
                    SOURCE32="$SMSLNX32" ;;
         HP-UX)     SOURCE="$SMSHP" ;;
         HP-UX_ia64) SOURCE="$SMSHPI" ;;
         AIX)       SOURCE="$SMSIBM" ;;
         *) printf "\n\nProgrammer error in install script -- exiting\n" >&2
            exit 1
            ;;
      esac

      Progress begin VRAND/SMS

      cd "$TODIR"

      Progress dot

      DeTarZ "$SMSMI" "VRAND/SMS"
      DeTarZ "$SOURCE" "VRAND/SMS"
      test x"$SOURCE32" != x && DeTarZ "$SOURCE32" "VRAND/SMS"

      Progress dot
#
#  make the vrandsms script
#
      if [ ! -d vrand/bin ]; then
         mkdir -p vrand/bin
         chmod a+rx vrand/bin
      fi
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          "$NASSMS" > vrand/bin/nastran_vrandsms
#
      chmod a+rx vrand/bin/nastran_vrandsms
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          -e "s?\"ZZZdefault_lenvecZZZ\"?\"$LENVEC\"?" \
          "$VRANDSMS" > vrand/sms/VRANDSMS
#
      chmod a+rx vrand/sms/VRANDSMS

      if [ ! -d vrand/licenses ]; then
         mkdir vrand/licenses
         chmod a+rx vrand/licenses
      fi

      Progress dot
#
#     install the FLEXlm lmutil program
#
      DeTarZOnly "$FLEXLM" "vrand/flexlm/$TARGET/lmutil" "flexlm"
      DeTarZOnly "$FLEXLM" "vrand/flexlm/doc" "flexlm"
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          "$LMU" > vrand/bin/lmutil
#
      chmod a+rx vrand/bin/lmutil
      test -f vrand/bin/lmhostid && rm vrand/bin/lmhostid
      ln vrand/bin/lmutil vrand/bin/lmhostid

      Progress end
#
   fi
###############################################################################
#
# install FLEXlm (if desired)
#
###############################################################################
   if [ $ISSET3 = true ]; then

      cd "$TODIR"

      Progress begin "FLEXlm"
#
      DeTarZOnly "$FLEXLM" "vrand/flexlm/$TARGET" "flexlm"

      Progress dot
#
      DeTarZOnly "$FLEXLM" "vrand/flexlm/doc" "flexlm"

      Progress dot
#
      if [ ! -d vrand/bin ]; then
         mkdir -p vrand/bin
         chmod a+rx vrand/bin
      fi
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          "$LMG" > vrand/bin/lmgrd
#
      chmod a+rx vrand/bin/lmgrd

      Progress dot
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          "$LMU" > vrand/bin/lmutil
#
      chmod a+rx vrand/bin/lmutil
      test -f vrand/bin/lmcksum   && rm vrand/bin/lmcksum
      test -f vrand/bin/lmdiag    && rm vrand/bin/lmdiag
      test -f vrand/bin/lmdown    && rm vrand/bin/lmdown
      test -f vrand/bin/lmhostid  && rm vrand/bin/lmhostid
      test -f vrand/bin/lminstall && rm vrand/bin/lminstall
      test -f vrand/bin/lmremove  && rm vrand/bin/lmremove
      test -f vrand/bin/lmreread  && rm vrand/bin/lmreread
      test -f vrand/bin/lmnewlog  && rm vrand/bin/lmnewlog
      test -f vrand/bin/lmswitchr && rm vrand/bin/lmswitchr
      test -f vrand/bin/lmstat    && rm vrand/bin/lmstat
      test -f vrand/bin/lmver     && rm vrand/bin/lmver
      ln vrand/bin/lmutil vrand/bin/lmcksum
      ln vrand/bin/lmutil vrand/bin/lmdiag
      ln vrand/bin/lmutil vrand/bin/lmdown
      ln vrand/bin/lmutil vrand/bin/lmhostid
      ln vrand/bin/lmutil vrand/bin/lminstall
      ln vrand/bin/lmutil vrand/bin/lmremove
      ln vrand/bin/lmutil vrand/bin/lmreread
      ln vrand/bin/lmutil vrand/bin/lmnewlog
      ln vrand/bin/lmutil vrand/bin/lmswitchr
      ln vrand/bin/lmutil vrand/bin/lmstat
      ln vrand/bin/lmutil vrand/bin/lmver

      Progress end
   fi
###############################################################################
#
# install the online manuals (if desired)
#
###############################################################################
###############################################################################
#
# print success messages
#
###############################################################################
if [ $ISSET1 = true -o $ISSET3 = true ]; then
if [ $ISSET3 = true ]; then
   Network="        Network: Yes"
else
   Network="        Network: No"
fi
Product="        Product: VRAND/SMS ${SMSVER}"
ReqDate="   Request Date: `date +%d-%b-%Y`"
case `uname` in
   AIX*)
SYSTEMTYPE="`uname -s` `uname -v`.`uname -r`"
   ;; 
   HP-UX)
SYSTEMTYPE="`/usr/bin/uname -sr` `model` `/usr/bin/getconf _SC_CPU_VERSION`"
   ;; 
   SunOS)
SYSTEMTYPE="`/usr/bin/uname -sri`"
   ;; 
   *)
SYSTEMTYPE="`uname -srm`"
   ;; 
esac
HOSTNAME=`hostname`
HOSTID=`"$TODIR/vrand/bin/lmhostid" -n`
if [ -f "$TODIR/vrand/license_request_form.txt" ]; then
mv "$TODIR/vrand/license_request_form.txt" "$TODIR/vrand/old_license_request.txt.old"
fi
cat <<EOF3 > "$TODIR/vrand/license_request_form.txt"
This system information is used to create the VRAND/SMS authorization file.
If you have purchased/leased a VRAND/SMS license, 
or you have arranged to receive a no-cost evaluation license,
fill in the following information and send this file to VR&D or
to your distributor:

(VR&D email: license@vrand.com)

Client Information
   Organization: 
 Contact Person: 
        Address: 
               : 
               : 
          Email: 
          Phone: 
            Fax: 
$ReqDate
   License Type: (mark one) Commercial  [ ]
                            Educational [ ]
                            Evaluation  [ ]
$Network

System Information
    System Type: $SYSTEMTYPE
       Hostname: $HOSTNAME
       LMHostid: $HOSTID

Product Information
$Product
EOF3
fi
   FINISHMSG=""
   if [ $ISSET1 = true ]; then
      FINISHMSG="$FINISHMSG
VRAND/SMS was successfully installed in
$TODIR/vrand

The script $TODIR/vrand/bin/nastran_vrandsms shows how to run Nastran
so that it uses the VRAND/SMS eigensolver.
"

   fi
   if [ $ISSET3 = true ]; then
      FINISHMSG="$FINISHMSG

The FLEXlm license server for VRAND/SMS was installed in
$TODIR/vrand

Start the license server by running the script
$TODIR/vrand/bin/lmgrd

You can read the FLEXlm End-User Documentation in
$TODIR/vrand/flexlm/doc/enduser.pdf"
   fi
   if [ $ISSET1 = true -o $ISSET3 = true ]; then
      FINISHMSG="$FINISHMSG

Use the file $TODIR/vrand/license_request_form.txt
to request a VRAND/SMS authorization file from Vanderplaats R&D or your
distributor. When you receive the license file, save it as vrandsms.lic in
$TODIR/vrand/licenses"
   fi

   printf "$FINISHMSG \n\n"

   echo "$FINISHMSG" > "$INSTALLLOG"
   printf "A log of the installation is saved in 
$INSTALLLOG \n" >&2

