#!/bin/ksh
#
##################################################
# VRANDSMS_ISHELL version 10.1 Workstation/Server
# ISHELL script file to run the vrandsms
# External Matrix Eigenvalue Solver
##################################################
#
#####################################################
#####               Copyright 2008              #####
##### Vanderplaats Research & Development, Inc. #####
#####            All rights reserved.           #####
#####################################################
#
##############################################################################
#  Start of user modifiable part -- Set these variables accordingly
##############################################################################
#
#  VRAND_PATH should be the  path to the installation directory + /vrand
#
test "x$VRAND_PATH" = x && VRAND_PATH="ZZZvrand_pathZZZ"
#
#  DEFAULT_LENVEC should be the default amount of memory for SMS (in words)
#
DEFAULT_LENVEC="ZZZdefault_lenvecZZZ"
#
# 821:METIS, 823:MMD, 824:SMOOTH HYBRID, 825:SMOOTH ND
SMS_ORDER_METHOD=${SMS_ORDER_METHOD:-821}
#
export FF_IO_DEFAULTS="$SMS_FF_IO_DEFAULTS"
export FF_IO_OPTS="$SMS_FF_IO_OPTS"
export FF_IO_LOGFILE="$SMS_FF_IO_LOGFILE"
#export FF_IO_OPEN_DIAGS="$SMS_FF_IO_OPEN_DIAGS"
#export FF_IO_RECOVER_CMD="$SMS_FF_IO_RECOVER_CMD"
#
##############################################################################
#  End of user modifiable part -- NOTHING BELOW THIS LINE SHOULD BE CHANGED!
##############################################################################
#
# 2008-12-12 !  if SMS_SCRATCH is set then change to that directory
if [ x"$SMS_SCRATCH" != x ]; then
   cd "$SMS_SCRATCH"
fi
#
command="$(basename $0)"
#
Usage()
{
   printf "Usage: $command \"0 1 2 0 0 0 NMODES 0 -1 -1 F1 F2\"
     Run vrandsms for external matrix eigenanalysis
     The stiffness matrix must be in the file VRANDSMS.EK
     and the  mass matrix must be in the file VRANDSMS.EM
     (both in NASTRAN OUTPUT4 format)\n" >&2
   exit 1
}
#
OSTYPE=`uname`
case $OSTYPE in
   AIX*)  OSTYPE="AIX"  ;;
   IRIX*) OSTYPE="IRIX" ;;
   UNIX_System_V) OSTYPE="vpp5000" ;;
   UNICOS*) OSTYPE="UNICOS" ;;
   Linux) OSTYPE="Linux_ix86"
      case `uname -m` in
         ia64*) OSTYPE="Linux_ia64" ;;
      esac
   ;;
   HP-UX)
      case `model` in
         ia64*) OSTYPE="HP-UX_ia64" ;;
      esac
   ;;
esac
#
if [ ! -d "$VRAND_PATH" ]; then
   what=`basename "$0"`
   where=`dirname "$0"`
   here=`pwd`
   test x"$where" = x. && where="$here"
   case $where in
      /*) : ;;
      *) where="$here/$where" ;;
   esac
   while [ -L "$where/$what" ]; do
      ls=`/bin/ls -l "$where/$what"`
      cmd=`expr "$ls" : ".*-> \(.*\)"`
      what=`basename "$cmd"`
      newwhere=`dirname "$cmd"`
      test x"$newwhere" = x. && newwhere="$where"
      case $newwhere in
         /*) : ;;
         *) newwhere="$where/$newwhere" ;;
      esac
      where="$newwhere"
   done
   case $where in
      */vrand/sms) 
         VRAND_PATH=`expr "$where" : "\(.*\)/sms"`
      ;;
      *) printf "Error: Vrand/SMS was not properly installed!
       Edit the VRANDSMS script and set the variable \"VRAND_PATH\"
       to the full path to the vrand directory.
" >&2
         exit 1
      ;;
   esac
fi
#
if [ "x$VRANDSMS_EXEC" = x ]; then
#
#  standard name for the vrandsms executable
#
   VRANDSMS_EXEC="$VRAND_PATH/sms/$OSTYPE/vrandsms.x"
#
fi
#
eval set -A argv $@
if [ "${argv[2]}" -ne 2 ]; then Usage; fi
NMODES="${argv[6]}"
if [ "$NMODES" -le 0 ]; then
   NMODES=
fi
# 2003-09-18 -- BCW
case "${argv[22]}" in
   *YES*) SMSRESV=1
   ;;
   *) SMSRESV=0
   ;;
esac
#
# 2004-01-29 -- BCW
case "${argv[23]}" in
   *YES*) SMSDRED=1
   ;;
   *) SMSDRED=0
   ;;
esac
#
# 2006-08-02 -- BCW
SMSSERC=0
if [ "${argv[1]}" -gt 1 -a "${argv[7]}" -gt 0 ]; then
   SMSSERC=1
fi
#
case "$OSTYPE" in
   IRIX|vpp5000)
F1="${argv[10]}"
F2="${argv[11]}"
   ;;
   *)
F1="$(printf %8.1f ${argv[10]})"
set -- $F1
F1=$1
if [ x"$F1" = x0.0 ]; then
   F1=
fi
F2="$(printf %8.1f ${argv[11]})"
set -- $F2
F2=$1
if [ x"$F2" = x0.0 ]; then
   F2=
fi
   ;;
esac
NMODES="$(printf %s $NMODES)"
set -- $NMODES
NMODES=$1
#
if [ ! -f VRANDSMS.EK ]; then 
   printf "External stiffness matrix file not found!\n\n" >&2
   Usage
fi
if [ ! -f VRANDSMS.EM ]; then
   printf "External mass matrix file not found!\n\n" >&2
   Usage
fi
if [ x"$SMSRESV" = x1 ]; then
if [ ! -f VRANDSMS.EP ]; then
   printf "External load matrix file not found!\n\n" >&2
   Usage
fi
fi
#
VRANDSMSDAT="VRANDSMS.dat"
VRANDSMSOUT="VRANDSMS.out"
#
DIAG78=${SMSSERC}${SMSDRED}${SMSRESV}

test x"$SMS_PARAM1" = x && SMS_PARAM1=7.0
test x"$SMS_PARAM2" = x && SMS_PARAM2=2.0
test x"$SMS_PARAM3" = x && SMS_PARAM3=1.4
test x"$SMS_SIGMA" = x && SMS_SIGMA=0.0
test x"$SMS_RVLIM" = x && SMS_RVLIM=0.01
test x"$SMS_RVGSTRIES" = x && SMS_RVGSTRIES=2
test x"$SMS_RVGSTOL" = x && SMS_RVGSTOL=1.0E-6

#
# Make SMS input file
#
cat > "$VRANDSMSDAT" <<EOF
ID VRANDSMS
DIAG=84
DIAG=$SMS_ORDER_METHOD
EOF
if [ "$DIAG78" -ne 0 ]; then
cat >> "$VRANDSMSDAT" <<EOFA
DIAG=78$DIAG78
EOFA
fi
if [ x"$SMS_DEBUG" != x ]; then
cat >> "$VRANDSMSDAT" <<EOFB
DIAG=324
EOFB
fi
if [ x"$SMS_EXTRA_DIAGS" != x ]; then
cat >> "$VRANDSMSDAT" <<EOFB2
DIAG=$SMS_EXTRA_DIAGS
EOFB2
fi
cat >> "$VRANDSMSDAT" <<EOFC
EXTERNAL=OUTPUT4
CEND
ECHO=NONE
LINE=64,80
LOADCASE 1
METHOD=1
BEGIN BULK
EIGR,1,SMS,$F1,$F2,,$NMODES
PARAM,SMS1,$SMS_PARAM1
PARAM,SMS2,$SMS_PARAM2
PARAM,SMS3,$SMS_PARAM3
PARAM,RPRM2,$SMS_SIGMA
PARAM,RPRM3,$SMS_RVLIM
PARAM,IPRM3,$SMS_RVGSTRIES
PARAM,RPRM4,$SMS_RVGSTOL
EOFC
#
# Rest of SMS input file
#
cat >> "$VRANDSMSDAT" <<EOFX
$
$ DUMMY GRID/ELEMENT/PROPERTY FOR READ ROUTINE
$
GRID           1             0.0                           23456
CELAS1         1       1       1       1
PELAS          1     1.0             1.0
CONM2          2       1             1.0
ENDDATA
EOFX
#
export VRAND_PATH
#
# number of threads for SMP parallel
export GENESIS_THREADS="$SMS_THREADS"
#
# io buffer controls
test x"$SMS_IOBNUM" = x && SMS_IOBNUM=64
test x"$SMS_IOBSIZ" = x && SMS_IOBSIZ=256K
export GENESIS_IOBUFF="$SMS_IOBNUM","$SMS_IOBSIZ"
#
if [ x"$SMS_MEM" = x ]; then
   SMS_MEM="$sms_mem"
fi
case $SMS_MEM in
   *mb) GENESIS_LENVEC=`expr "${SMS_MEM%mb}" \* 250000`
   ;;
   *Mb) GENESIS_LENVEC=`expr "${SMS_MEM%Mb}" \* 250000`
   ;;
   *MB) GENESIS_LENVEC=`expr "${SMS_MEM%MB}" \* 250000`
   ;;
   *mw) GENESIS_LENVEC=`expr "${SMS_MEM%mw}" \* 1000000`
   ;;
   *Mw) GENESIS_LENVEC=`expr "${SMS_MEM%Mw}" \* 1000000`
   ;;
   *MW) GENESIS_LENVEC=`expr "${SMS_MEM%MW}" \* 1000000`
   ;;
   *0) GENESIS_LENVEC="$SMS_MEM"
   ;;
   *) GENESIS_LENVEC="$DEFAULT_LENVEC"
   ;;
esac
if [ x"$SMS_DEBUG" != x ]; then
   echo File listing before SMS execution >&2
   ls -l VRANDSMS* >&2
fi
export GENESIS_LENVEC
unset LM_LICENSE_FILE
test -f ~/.flexlmrc && mv ~/.flexlmrc ~/.flexlmrc.$$
#echo "$VRANDSMS_EXEC" "$VRANDSMSDAT"
"$VRANDSMS_EXEC" "$VRANDSMSDAT"
awk '/^  *ERROR MESSAGE/,/^$/' "$VRANDSMSOUT" >&2
test -f ~/.flexlmrc.$$ && mv ~/.flexlmrc.$$ ~/.flexlmrc
#
if [ x"$SMS_DEBUG" = x ]; then
   rm -f "$VRANDSMSDAT"
   ###cat "$VRANDSMSOUT" >&2
   rm -f "$VRANDSMSOUT"
else
   echo File listing after SMS execution >&2
   ls -l VRANDSMS* >&2
   if [ `grep "WARNING" $VRANDSMSOUT |wc -l` -ne 0 ] ;then
      cat $VRANDSMSOUT >&2
   fi
   if [ "x$SMS_FF_IO_LOGFILE" != x ] ;then
      cat $SMS_FF_IO_LOGFILE >> $VRANDSMSOUT
   fi
   if [ "x$SMS_SYSLOGDIR" != x ]; then
      test -d "$SMS_SYSLOGDIR" || ( mkdir -p "$SMS_SYSLOGDIR" && chmod a+rwx "$SMS_SYSLOGDIR" )
      cp "$VRANDSMSOUT" "${SMS_SYSLOGDIR}/$VRANDSMSOUT"_`date +%y%m%d`_$$
   else
      cp "$VRANDSMSOUT" "$VRANDSMSOUT"_`date +%y%m%d`_$$
   fi
fi
# 2006-02-15  --  GCQ for MSC/NASTRAN V2005
#echo "${argv[24]}"
if [ x"${argv[24]}" = xYES ]; then
#mv VRANDSMS.EE2 VRANDSMS.EE3
cp VRANDSMS.EE2 VRANDSMS.EE3
fi
exit 0
